#include <iostream>
#include <pcl/point_cloud.h>
#include <pcl/io/pcd_io.h>
#include <pcl/point_types.h>
#include <pcl/visualization/cloud_viewer.h>

#ifdef __linux__
#include <unistd.h>
#endif

/*
 * Sample code for reading point clouds in the RGB-D Object Dataset using the Point Cloud Library
 *
 * Adapted from code by: Kevin Lai
 */

int main (int argc, char** argv)
{

  if(argc < 2){
    printf ("Usage: <name.pcd>\n");
    return(0);
  }

  pcl::PointCloud<pcl::PointXYZRGB>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZRGB>);

  if (pcl::io::loadPCDFile<pcl::PointXYZRGB> (argv[1], *cloud) == -1) //* load the file
  {
    printf ("Couldn't input file \n");
    return (-1);
  }
  std::cout << "Loaded "
            << cloud->width * cloud->height
            << " data points\n";
            
  pcl::visualization::CloudViewer viewer("Viewer");
  viewer.showCloud (cloud);
  while (!viewer.wasStopped ()){
    #ifdef __linux__
    sleep(1);
    #endif
  }

  return (0);
}
